Examples
========

.. grid::

    .. grid-item-card:: GWTC3
        :link: GWTC3.html
        :link-alt: Population Inference with the Third Gravitational-Wave Transient Catalog

        Population inference with the third gravitational-wave transient catalog

.. grid::

    .. grid-item-card:: GWTC1
        :link: GWTC1.html
        :link-alt: Population Inference with the First Gravitational-Wave Transient Catalog

        Population inference with the first gravitational-wave transient catalog


.. toctree::
   :hidden:

   GWTC1
   GWTC3

External Examples
-----------------

.. grid::

    .. grid-item-card:: Spectral Siren Cosmology
        :link: https://wcosmo.readthedocs.io/en/latest/examples/gwtc3.html

        Spectral siren cosmology with the third gravitational-wave transient catalog

.. attention::

   If you have an example you would like to link to from here, please open an issue or pull request to add a link to this page!
